@@ -153,10 +153,7 @@ class Tracer(object):
         # at least raise that limit to 80 chars, which should be enough for
         # most interactive uses.
         try:
-            try:
-                from reprlib import aRepr  # Py 3
-            except ImportError:
-                from repr import aRepr  # Py 2
+            from reprlib import aRepr
             aRepr.maxstring = 80
         except:
             # This is only a user-facing convenience, so any error we encounter
@@ -195,21 +192,6 @@ def decorate_fn_with_doc(new_fn, old_fn, additional_text=""):
     return wrapper
 
 
-def _file_lines(fname):
-    """Return the contents of a named file as a list of lines.
-
-    This function never raises an IOError exception: if the file can't be
-    read, it simply returns an empty list."""
-
-    try:
-        outfile = open(fname)
-    except IOError:
-        return []
-    else:
-        with out:
-            return outfile.readlines()
-
-
 class Pdb(OldPdb):
     """Modified Pdb class, does not load readline.
 
@@ -219,7 +201,19 @@ class Pdb(OldPdb):
     """
 
     def __init__(self, color_scheme=None, completekey=None,
-                 stdin=None, stdout=None, context=5):
+                 stdin=None, stdout=None, context=5, **kwargs):
+        """Create a new IPython debugger.
+        
+        :param color_scheme: Deprecated, do not use.
+        :param completekey: Passed to pdb.Pdb.
+        :param stdin: Passed to pdb.Pdb.
+        :param stdout: Passed to pdb.Pdb.
+        :param context: Number of lines of source code context to show when
+            displaying stacktrace information.
+        :param kwargs: Passed to pdb.Pdb.
+            The possibilities are python version dependent, see the python
+            docs for more info.
+        """
 
         # Parent constructor:
         try:
@@ -229,7 +223,8 @@ class Pdb(OldPdb):
         except (TypeError, ValueError):
                 raise ValueError("Context must be a positive integer")
 
-        OldPdb.__init__(self, completekey, stdin, stdout)
+        # `kwargs` ensures full compatibility with stdlib's `pdb.Pdb`.
+        OldPdb.__init__(self, completekey, stdin, stdout, **kwargs)
 
         # IPython changes...
         self.shell = get_ipython()
@@ -627,7 +622,11 @@ class Pdb(OldPdb):
         Take a number as argument as an (optional) number of context line to
         print"""
         if arg:
-            context = int(arg)
+            try:
+                context = int(arg)
+            except ValueError as err:
+                self.error(err)
+                return
             self.print_stack_trace(context)
         else:
             self.print_stack_trace()
@@ -635,6 +634,34 @@ class Pdb(OldPdb):
     do_w = do_where
 
 
+class InterruptiblePdb(Pdb):
+    """Version of debugger where KeyboardInterrupt exits the debugger altogether."""
+
+    def cmdloop(self):
+        """Wrap cmdloop() such that KeyboardInterrupt stops the debugger."""
+        try:
+            return OldPdb.cmdloop(self)
+        except KeyboardInterrupt:
+            self.stop_here = lambda frame: False
+            self.do_quit("")
+            sys.settrace(None)
+            self.quitting = False
+            raise
+
+    def _cmdloop(self):
+        while True:
+            try:
+                # keyboard interrupts allow for an easy way to cancel
+                # the current command, so allow them during interactive input
+                self.allow_kbdint = True
+                self.cmdloop()
+                self.allow_kbdint = False
+                break
+            except KeyboardInterrupt:
+                self.message('--KeyboardInterrupt--')
+                raise
+
+
 def set_trace(frame=None):
     """
     Start debugging from `frame`.
